import * as path from "path";

export const rootDir = path.join(__dirname, "..", "..");
export const uploadDir = path.join(rootDir, "uploads");
export const COOKIE_NAME = "BLISS_AUTH";
export const INVITE_PREFIX = "invite:";

export enum GENERATOR_TYPE {
	TEXT = "text",
	ZEROWIDTH = "zerowidth",
	EMOJI = "emoji"
}

export const charsets = {
	text: "QWERTYUIOPASDFGHJKLZXCVBNMqwertyuiopasdfghjklzxcvbnm1234567890",
	zerowidth: ["\u200B", "\u2060", "\u200C", "\u200D"],
	emoji: [
		"😄",
		"😃",
		"😀",
		"😊",
		"☺",
		"😉",
		"😍",
		"😘",
		"😚",
		"😗",
		"😙",
		"😜",
		"😝",
		"😛",
		"😳",
		"😁",
		"😔",
		"😌",
		"😒",
		"😞",
		"😣",
		"😢",
		"😂",
		"😭",
		"😪",
		"😥",
		"😰",
		"😅",
		"😓",
		"😩",
		"😫",
		"😨",
		"😱",
		"😠",
		"😡",
		"😤",
		"😖",
		"😆",
		"😋",
		"😷",
		"😎",
		"😴",
		"😵",
		"😲",
		"😟",
		"😦",
		"😧",
		"😈",
		"👿",
		"😮",
		"😬",
		"😐",
		"😕",
		"😯",
		"😶",
		"😇",
		"😏",
		"😑",
		"👲",
		"👳",
		"👮",
		"👷",
		"💂",
		"👶",
		"👦",
		"👧",
		"👨",
		"👩",
		"👴",
		"👵",
		"👱",
		"👼",
		"👸",
		"😺",
		"😸",
		"😻",
		"😽",
		"😼",
		"🙀",
		"😿",
		"😹",
		"😾",
		"👹",
		"👺",
		"🙈",
		"🙉",
		"🙊",
		"💀",
		"👽",
		"💩",
		"🔥",
		"✨",
		"🌟",
		"💫",
		"💥",
		"💢",
		"💦",
		"💧",
		"💤",
		"💨",
		"👂",
		"👀",
		"👃",
		"👅",
		"👄",
		"👍",
		"👎",
		"👌",
		"👊",
		"✊",
		"✌",
		"👋",
		"✋",
		"👐",
		"👆",
		"👇",
		"👉",
		"👈",
		"🙌",
		"🙏",
		"☝",
		"👏",
		"💪",
		"🚶",
		"🏃",
		"💃",
		"👫",
		"👪",
		"👬",
		"👭",
		"💏",
		"💑",
		"👯",
		"🙆",
		"🙅",
		"💁",
		"🙋",
		"💆",
		"💇",
		"💅",
		"👰",
		"🙎",
		"🙍",
		"🙇",
		"🎩",
		"👑",
		"👒",
		"👟",
		"👞",
		"👡",
		"👠",
		"👢",
		"👕",
		"👔",
		"👚",
		"👗",
		"🎽",
		"👖",
		"👘",
		"👙",
		"💼",
		"👜",
		"👝",
		"👛",
		"👓",
		"🎀",
		"🌂",
		"💄",
		"💛",
		"💙",
		"💜",
		"💚",
		"❤",
		"💔",
		"💗",
		"💓",
		"💕",
		"💖",
		"💞",
		"💘",
		"💌",
		"💋",
		"💍",
		"💎",
		"👤",
		"👥",
		"💬",
		"👣",
		"💭",
		"🐶",
		"🐺",
		"🐱",
		"🐭",
		"🐹",
		"🐰",
		"🐸",
		"🐯",
		"🐨",
		"🐻",
		"🐷",
		"🐽",
		"🐮",
		"🐗",
		"🐵",
		"🐒",
		"🐴",
		"🐑",
		"🐘",
		"🐼",
		"🐧",
		"🐦",
		"🐤",
		"🐥",
		"🐣",
		"🐔",
		"🐍",
		"🐢",
		"🐛",
		"🐝",
		"🐜",
		"🐞",
		"🐌",
		"🐙",
		"🐚",
		"🐠",
		"🐟",
		"🐬",
		"🐳",
		"🐋",
		"🐄",
		"🐏",
		"🐀",
		"🐃",
		"🐅",
		"🐇",
		"🐉",
		"🐎",
		"🐐",
		"🐓",
		"🐕",
		"🐖",
		"🐁",
		"🐂",
		"🐲",
		"🐡",
		"🐊",
		"🐫",
		"🐪",
		"🐆",
		"🐈",
		"🐩",
		"🐾",
		"💐",
		"🌸",
		"🌷",
		"🍀",
		"🌹",
		"🌻",
		"🌺",
		"🍁",
		"🍃",
		"🍂",
		"🌿",
		"🌾",
		"🍄",
		"🌵",
		"🌴",
		"🌲",
		"🌳",
		"🌰",
		"🌱",
		"🌼",
		"🌐",
		"🌞",
		"🌝",
		"🌚",
		"🌑",
		"🌒",
		"🌓",
		"🌔",
		"🌕",
		"🌖",
		"🌗",
		"🌘",
		"🌜",
		"🌛",
		"🌙",
		"🌍",
		"🌎",
		"🌏",
		"🌋",
		"🌌",
		"🌠",
		"⭐",
		"☀",
		"⛅",
		"☁",
		"⚡",
		"☔",
		"❄",
		"⛄",
		"🌀",
		"🌁",
		"🌈",
		"🌊",
		"🎍",
		"💝",
		"🎎",
		"🎒",
		"🎓",
		"🎏",
		"🎆",
		"🎇",
		"🎐",
		"🎑",
		"🎃",
		"👻",
		"🎅",
		"🎄",
		"🎁",
		"🎋",
		"🎉",
		"🎊",
		"🎈",
		"🎌",
		"🔮",
		"🎥",
		"📷",
		"📹",
		"📼",
		"💿",
		"📀",
		"💽",
		"💾",
		"💻",
		"📱",
		"☎",
		"📞",
		"📟",
		"📠",
		"📡",
		"📺",
		"📻",
		"🔊",
		"🔉",
		"🔈",
		"🔇",
		"🔔",
		"🔕",
		"📢",
		"📣",
		"⏳",
		"⌛",
		"⏰",
		"⌚",
		"🔓",
		"🔒",
		"🔏",
		"🔐",
		"🔑",
		"🔎",
		"💡",
		"🔦",
		"🔆",
		"🔅",
		"🔌",
		"🔋",
		"🔍",
		"🛁",
		"🛀",
		"🚿",
		"🚽",
		"🔧",
		"🔩",
		"🔨",
		"🚪",
		"🚬",
		"💣",
		"🔫",
		"🔪",
		"💊",
		"💉",
		"💰",
		"💴",
		"💵",
		"💷",
		"💶",
		"💳",
		"💸",
		"📲",
		"📧",
		"📥",
		"📤",
		"✉",
		"📩",
		"📨",
		"📯",
		"📫",
		"📪",
		"📬",
		"📭",
		"📮",
		"📦",
		"📝",
		"📄",
		"📃",
		"📑",
		"📊",
		"📈",
		"📉",
		"📜",
		"📋",
		"📅",
		"📆",
		"📇",
		"📁",
		"📂",
		"✂",
		"📌",
		"📎",
		"✒",
		"✏",
		"📏",
		"📐",
		"📕",
		"📗",
		"📘",
		"📙",
		"📓",
		"📔",
		"📒",
		"📚",
		"📖",
		"🔖",
		"📛",
		"🔬",
		"🔭",
		"📰",
		"🎨",
		"🎬",
		"🎤",
		"🎧",
		"🎼",
		"🎵",
		"🎶",
		"🎹",
		"🎻",
		"🎺",
		"🎷",
		"🎸",
		"👾",
		"🎮",
		"🃏",
		"🎴",
		"🀄",
		"🎲",
		"🎯",
		"🏈",
		"🏀",
		"⚽",
		"⚾",
		"🎾",
		"🎱",
		"🏉",
		"🎳",
		"⛳",
		"🚵",
		"🚴",
		"🏁",
		"🏇",
		"🏆",
		"🎿",
		"🏂",
		"🏊",
		"🏄",
		"🎣",
		"☕",
		"🍵",
		"🍶",
		"🍼",
		"🍺",
		"🍻",
		"🍸",
		"🍹",
		"🍷",
		"🍴",
		"🍕",
		"🍔",
		"🍟",
		"🍗",
		"🍖",
		"🍝",
		"🍛",
		"🍤",
		"🍱",
		"🍣",
		"🍥",
		"🍙",
		"🍘",
		"🍚",
		"🍜",
		"🍲",
		"🍢",
		"🍡",
		"🍳",
		"🍞",
		"🍩",
		"🍮",
		"🍦",
		"🍨",
		"🍧",
		"🎂",
		"🍰",
		"🍪",
		"🍫",
		"🍬",
		"🍭",
		"🍯",
		"🍎",
		"🍏",
		"🍊",
		"🍋",
		"🍒",
		"🍇",
		"🍉",
		"🍓",
		"🍑",
		"🍈",
		"🍌",
		"🍐",
		"🍍",
		"🍠",
		"🍆",
		"🍅",
		"🌽",
		"🏠",
		"🏡",
		"🏫",
		"🏢",
		"🏣",
		"🏥",
		"🏦",
		"🏪",
		"🏩",
		"🏨",
		"💒",
		"⛪",
		"🏬",
		"🏤",
		"🌇",
		"🌆",
		"🏯",
		"🏰",
		"⛺",
		"🏭",
		"🗼",
		"🗾",
		"🗻",
		"🌄",
		"🌅",
		"🌃",
		"🗽",
		"🌉",
		"🎠",
		"🎡",
		"⛲",
		"🎢",
		"🚢",
		"⛵",
		"🚤",
		"🚣",
		"⚓",
		"🚀",
		"✈",
		"💺",
		"🚁",
		"🚂",
		"🚊",
		"🚉",
		"🚞",
		"🚆",
		"🚄",
		"🚅",
		"🚈",
		"🚇",
		"🚝",
		"🚋",
		"🚃",
		"🚎",
		"🚌",
		"🚍",
		"🚙",
		"🚘",
		"🚗",
		"🚕",
		"🚖",
		"🚛",
		"🚚",
		"🚨",
		"🚓",
		"🚔",
		"🚒",
		"🚑",
		"🚐",
		"🚲",
		"🚡",
		"🚟",
		"🚠",
		"🚜",
		"💈",
		"🚏",
		"🎫",
		"🚦",
		"🚥",
		"⚠",
		"🚧",
		"🔰",
		"⛽",
		"🏮",
		"🎰",
		"♨",
		"🗿",
		"🎪",
		"🎭",
		"📍",
		"🚩",
		"⬆",
		"⬇",
		"⬅",
		"➡",
		"🔠",
		"🔡",
		"🔤",
		"↗",
		"↖",
		"↘",
		"↙",
		"↔",
		"↕",
		"🔄",
		"◀",
		"▶",
		"🔼",
		"🔽",
		"↩",
		"↪",
		"ℹ",
		"⏪",
		"⏩",
		"⏫",
		"⏬",
		"⤵",
		"⤴",
		"🆗",
		"🔀",
		"🔁",
		"🔂",
		"🆕",
		"🆙",
		"🆒",
		"🆓",
		"🆖",
		"📶",
		"🎦",
		"🈁",
		"🈯",
		"🈳",
		"🈵",
		"🈴",
		"🈲",
		"🉐",
		"🈹",
		"🈺",
		"🈶",
		"🈚",
		"🚻",
		"🚹",
		"🚺",
		"🚼",
		"🚾",
		"🚰",
		"🚮",
		"🅿",
		"♿",
		"🚭",
		"🈷",
		"🈸",
		"🈂",
		"Ⓜ",
		"🛂",
		"🛄",
		"🛅",
		"🛃",
		"🉑",
		"㊙",
		"㊗",
		"🆑",
		"🆘",
		"🆔",
		"🚫",
		"🔞",
		"📵",
		"🚯",
		"🚱",
		"🚳",
		"🚷",
		"🚸",
		"⛔",
		"✳",
		"❇",
		"❎",
		"✅",
		"✴",
		"💟",
		"🆚",
		"📳",
		"📴",
		"🅰",
		"🅱",
		"🆎",
		"🅾",
		"💠",
		"➿",
		"♻",
		"♈",
		"♉",
		"♊",
		"♋",
		"♌",
		"♍",
		"♎",
		"♏",
		"♐",
		"♑",
		"♒",
		"♓",
		"⛎",
		"🔯",
		"🏧",
		"💹",
		"💲",
		"💱",
		"©",
		"®",
		"™",
		"〽",
		"〰",
		"🔝",
		"🔚",
		"🔙",
		"🔛",
		"🔜",
		"❌",
		"⭕",
		"❗",
		"❓",
		"❕",
		"❔",
		"🔃",
		"🕛",
		"🕧",
		"🕐",
		"🕜",
		"🕑",
		"🕝",
		"🕒",
		"🕞",
		"🕓",
		"🕟",
		"🕔",
		"🕠",
		"🕕",
		"🕖",
		"🕗",
		"🕘",
		"🕙",
		"🕚",
		"🕡",
		"🕢",
		"🕣",
		"🕤",
		"🕥",
		"🕦",
		"✖",
		"➕",
		"➖",
		"➗",
		"♠",
		"♥",
		"♣",
		"♦",
		"💮",
		"💯",
		"✔",
		"☑",
		"🔘",
		"🔗",
		"➰",
		"🔱",
		"🔲",
		"🔳",
		"◼",
		"◻",
		"◾",
		"◽",
		"▪",
		"▫",
		"🔺",
		"⬜",
		"⬛",
		"⚫",
		"⚪",
		"🔴",
		"🔵",
		"🔻",
		"🔶",
		"🔷",
		"🔸",
		"🔹"
	]
};
